@@ -27,16 +27,20 @@ class CControllerPopupConditionOperations extends CControllerPopupConditionCommo
 	protected function getCheckInputs() {
 		return [
 			'type' =>			'required|in '.ZBX_POPUP_CONDITION_TYPE_ACTION_OPERATION,
-			'source' =>			'required|in '.implode(',', [EVENT_SOURCE_TRIGGERS, EVENT_SOURCE_DISCOVERY, EVENT_SOURCE_AUTOREGISTRATION, EVENT_SOURCE_INTERNAL, EVENT_SOURCE_SERVICE]),
+			'source' =>			'required|in '.implode(',', [
+									EVENT_SOURCE_TRIGGERS, EVENT_SOURCE_DISCOVERY, EVENT_SOURCE_AUTOREGISTRATION,
+									EVENT_SOURCE_INTERNAL, EVENT_SOURCE_SERVICE
+								]),
 			'validate' =>		'in 1',
-			'condition_type' =>	'in '.CONDITION_TYPE_EVENT_ACKNOWLEDGED,
+			'condition_type' =>	'in '.ZBX_CONDITION_TYPE_EVENT_ACKNOWLEDGED,
 			'operator' =>		'in '.CONDITION_OPERATOR_EQUAL,
-			'value' =>			'in '.implode(',', [EVENT_NOT_ACKNOWLEDGED, EVENT_ACKNOWLEDGED])
+			'value' =>			'in '.implode(',', [EVENT_NOT_ACKNOWLEDGED, EVENT_ACKNOWLEDGED]),
+			'row_index' =>		'int32'
 		];
 	}
 
 	protected function getConditionLastType() {
-		return CONDITION_TYPE_EVENT_ACKNOWLEDGED;
+		return ZBX_CONDITION_TYPE_EVENT_ACKNOWLEDGED;
 	}
 
 	protected function validateFieldsManually() {
@@ -69,6 +73,7 @@ class CControllerPopupConditionOperations extends CControllerPopupConditionCommo
 			'command' => '',
 			'message' => '',
 			'errors' => null,
+			'row_index' => $this->getInput('row_index'),
 			'action' => $this->getAction(),
 			'type' => $this->getInput('type'),
 			'last_type' => $this->getConditionLastType(),
