@@ -46,7 +46,7 @@ class CControllerPopupSlaExcludedDowntimeEdit extends CController {
 			$validator = new CNewValidator(array_intersect_key($this->getInputAll(), $fields), $fields);
 
 			foreach ($validator->getAllErrors() as $error) {
-				info($error);
+				error($error);
 			}
 
 			$ret = !$validator->isErrorFatal() && !$validator->isError();
