@@ -54,7 +54,7 @@ $item_form_list = (new CFormList('item-form-list'))
 // Append hosts interface select to form list.
 if ($data['single_host_selected'] && $data['context'] === 'host') {
 	$item_form_list->addRow(
-		(new CVisibilityBox('visible[interfaceid]', 'interfaceDiv', _('Original')))
+		(new CVisibilityBox('visible[interfaceid]', 'interface-field', _('Original')))
 			->setLabel(_('Host interface'))
 			->setAttribute('data-multiple-interface-types', $data['multiple_interface_types']),
 		(new CDiv([
@@ -66,7 +66,7 @@ if ($data['single_host_selected'] && $data['context'] === 'host') {
 				->addClass(ZBX_STYLE_RED)
 				->setId('interface_not_defined')
 				->addStyle('display: none;')
-		]))->setId('interfaceDiv'),
+		]))->setId('interface-field'),
 		'interface_row'
 	);
 }
@@ -87,13 +87,12 @@ $item_form_list
 	->addRow(
 		(new CVisibilityBox('visible[post_type]', 'post_type_container', _('Original')))
 			->setLabel(_('Request body type')),
-		(new CDiv(
-			(new CRadioButtonList('post_type', (int) DB::getDefault('items', 'post_type')))
-				->addValue(_('Raw data'), ZBX_POSTTYPE_RAW)
-				->addValue(_('JSON data'), ZBX_POSTTYPE_JSON)
-				->addValue(_('XML data'), ZBX_POSTTYPE_XML)
-				->setModern(true)
-		))->setId('post_type_container')
+		(new CRadioButtonList('post_type', (int) DB::getDefault('items', 'post_type')))
+			->addValue(_('Raw data'), ZBX_POSTTYPE_RAW)
+			->addValue(_('JSON data'), ZBX_POSTTYPE_JSON)
+			->addValue(_('XML data'), ZBX_POSTTYPE_XML)
+			->setId('post_type_container')
+			->setModern(true)
 	)
 	->addRow(
 		(new CVisibilityBox('visible[timeout]', 'timeout', _('Original')))->setLabel(_('Timeout')),
@@ -102,7 +101,9 @@ $item_form_list
 	// Append ITEM_TYPE_HTTPAGENT Request body.
 	->addRow(
 		(new CVisibilityBox('visible[posts]', 'posts', _('Original')))->setLabel(_('Request body')),
-		(new CTextArea('posts', ''))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		(new CTextArea('posts', ''))
+			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+			->disableSpellcheck()
 	);
 
 // Append ITEM_TYPE_HTTPAGENT Headers fields.
@@ -129,7 +130,7 @@ $item_form_list
 				->addItem(new CRow([
 					(new CCol((new CDiv)->addClass(ZBX_STYLE_DRAG_ICON)))->addClass(ZBX_STYLE_TD_DRAG_ICON),
 					(new CTextBox('headers[name][#{index}]', '#{name}'))->setWidth(ZBX_TEXTAREA_HTTP_PAIR_NAME_WIDTH),
-					'&rArr;',
+					RARR(),
 					(new CTextBox('headers[value][#{index}]', '#{value}', false, 2000))
 						->setWidth(ZBX_TEXTAREA_HTTP_PAIR_VALUE_WIDTH),
 					(new CButton(null, _('Remove')))
@@ -204,19 +205,12 @@ $item_form_list
 $preprocessing_form_list = (new CFormList('preprocessing-form-list'))
 	// Append item pre-processing to form list.
 	->addRow(
-		(new CVisibilityBox('visible[preprocessing]', 'preprocessing_div', _('Original')))
+		(new CVisibilityBox('visible[preprocessing]', 'preprocessing-field', _('Original')))
 			->setLabel(_('Preprocessing steps')),
 		(new CDiv(getItemPreprocessing([], false, $data['preprocessing_types'])))
-			->setId('preprocessing_div')
+			->setId('preprocessing-field')
 	);
 
-// Prepare Update interval for form list.
-$update_interval = (new CTable())
-	->setId('update_interval')
-	->addRow([_('Delay'),
-		(new CDiv((new CTextBox('delay', ZBX_ITEM_DELAY_DEFAULT))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)))
-	]);
-
 $custom_intervals = (new CTable())
 	->setId('custom_intervals')
 	->setHeader([
@@ -269,23 +263,19 @@ $custom_intervals->addRow([(new CButton('interval_add', _('Add')))
 	->addClass(ZBX_STYLE_BTN_LINK)
 	->addClass('element-table-add')]);
 
-$update_interval->addRow(
-	(new CRow([
-		(new CCol(_('Custom intervals')))->addStyle('vertical-align: top;'),
-		new CCol($custom_intervals)
-	]))
-);
-
 // Append update interval to form list.
 $item_form_list
 	// Append delay to form list.
 	->addRow(
-		(new CVisibilityBox('visible[delay]', 'update_interval_div', _('Original')))->setLabel(_('Update interval')),
-		(new CDiv($update_interval))->setId('update_interval_div')
+		(new CVisibilityBox('visible[delay]', 'update_interval', _('Original')))->setLabel(_('Update interval')),
+		(new CFormList('update_interval'))
+			->addClass(ZBX_STYLE_TABLE_SUBFORMS)
+			->addRow(_('Delay'), (new CTextBox('delay', ZBX_ITEM_DELAY_DEFAULT))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH))
+			->addRow(_('Custom intervals'), $custom_intervals)
 	)
 	// Append history to form list.
 	->addRow(
-		(new CVisibilityBox('visible[history]', 'history_div', _('Original')))
+		(new CVisibilityBox('visible[history]', 'history-field', _('Original')))
 			->setLabel(_('History storage period')),
 		(new CDiv([
 			(new CRadioButtonList('history_mode', ITEM_STORAGE_CUSTOM))
@@ -298,11 +288,11 @@ $item_form_list
 				->setAriaRequired()
 		]))
 			->addClass('wrap-multiple-controls')
-			->setId('history_div')
+			->setId('history-field')
 	)
 	// Append trends to form list.
 	->addRow(
-		(new CVisibilityBox('visible[trends]', 'trends_div', _('Original')))->setLabel(_('Trend storage period')),
+		(new CVisibilityBox('visible[trends]', 'trends-field', _('Original')))->setLabel(_('Trend storage period')),
 		(new CDiv([
 			(new CRadioButtonList('trends_mode', ITEM_STORAGE_CUSTOM))
 				->addValue(_('Do not keep trends'), ITEM_STORAGE_OFF)
@@ -314,7 +304,7 @@ $item_form_list
 				->setAriaRequired()
 		]))
 			->addClass('wrap-multiple-controls')
-			->setId('trends_div')
+			->setId('trends-field')
 	);
 
 // Append status to form list.
@@ -346,26 +336,25 @@ $item_form_list->addRow(
 // Append value map select when only one host or template is selected.
 if ($data['single_host_selected'] && ($data['context'] === 'template' || !$data['discovered_host'])) {
 	$item_form_list->addRow(
-		(new CVisibilityBox('visible[valuemapid]', 'valuemapid_div', _('Original')))->setLabel(_('Value mapping')),
-		(new CDiv([
-			(new CMultiSelect([
-				'name' => 'valuemapid',
-				'object_name' => $data['context'] === 'host' ? 'valuemaps' : 'template_valuemaps',
-				'multiple' => false,
-				'data' => [],
-				'popup' => [
-					'parameters' => [
-						'srctbl' => $data['context'] === 'host' ? 'valuemaps' : 'template_valuemaps',
-						'srcfld1' => 'valuemapid',
-						'dstfrm' => $form->getName(),
-						'dstfld1' => 'valuemapid',
-						'hostids' => [$data['hostid']],
-						'context' => $data['context'],
-						'editable' => true
-					]
+		(new CVisibilityBox('visible[valuemapid]', 'valuemapid-field', _('Original')))->setLabel(_('Value mapping')),
+		(new CMultiSelect([
+			'name' => 'valuemapid',
+			'object_name' => $data['context'] === 'host' ? 'valuemaps' : 'template_valuemaps',
+			'multiselect_id' => 'valuemapid-field',
+			'multiple' => false,
+			'data' => [],
+			'popup' => [
+				'parameters' => [
+					'srctbl' => $data['context'] === 'host' ? 'valuemaps' : 'template_valuemaps',
+					'srcfld1' => 'valuemapid',
+					'dstfrm' => $form->getName(),
+					'dstfld1' => 'valuemapid',
+					'hostids' => [$data['hostid']],
+					'context' => $data['context'],
+					'editable' => true
 				]
-			]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-		]))->setId('valuemapid_div')
+			]
+		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 	);
 }
 
@@ -384,10 +373,13 @@ $item_form_list->addRow(
 // Append master item select to form list.
 if ($data['single_host_selected']) {
 	if (!$data['prototype']) {
-		$master_item = (new CDiv([
+		$item_form_list->addRow(
+			(new CVisibilityBox('visible[master_itemid]', 'master-item-field', _('Original')))
+				->setLabel(_('Master item')),
 			(new CMultiSelect([
 				'name' => 'master_itemid',
 				'object_name' => 'items',
+				'multiselect_id' => 'master-item-field',
 				'multiple' => false,
 				'data' => [],
 				'popup' => [
@@ -402,60 +394,57 @@ if ($data['single_host_selected']) {
 				]
 			]))
 				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-				->setAriaRequired(true)
-		]))->setId('master_item');
+				->setAriaRequired()
+		);
 	}
 	else {
-		$master_item = [
-			(new CTextBox('master_itemname', '', true))
-				->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-				->setAriaRequired(),
-			(new CVar('master_itemid', '', 'master_itemid'))
-		];
-
-		$master_item[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$master_item[] = (new CButton('button', _('Select')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->removeId()
-			->setAttribute('data-hostid', $data['hostid'])
-			->onClick('
-				PopUp("popup.generic", {
-					srctbl: "items",
-					srcfld1: "itemid",
-					srcfld2: "name",
-					dstfrm: "'.$form->getName().'",
-					dstfld1: "master_itemid",
-					dstfld2: "master_itemname",
-					only_hostid: this.dataset.hostid,
-					normal_only: 1
-				}, {dialogue_class: "modal-popup-generic"});
-			');
-
-		$master_item[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$master_item[] = (new CButton('button', _('Select prototype')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->removeId()
-			->setAttribute('data-parent_discoveryid', $data['parent_discoveryid'])
-			->onClick('
-				PopUp("popup.generic", {
-					srctbl: "item_prototypes",
-					srcfld1: "itemid",
-					srcfld2: "name",
-					dstfrm: "'.$form->getName().'",
-					dstfld1: "master_itemid",
-					dstfld2: "master_itemname",
-					parent_discoveryid: this.dataset.parent_discoveryid
-				}, {dialogue_class: "modal-popup-generic"});
-			');
+		$item_form_list->addRow(
+			(new CVisibilityBox('visible[master_itemid]', 'master_item-field', _('Original')))
+				->setLabel(_('Master item')),
+			(new CDiv([
+				(new CVar('master_itemname')),
+				[
+					(new CTextBox('master_itemname', '', true))
+						->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+						->setAriaRequired(),
+					(new CVar('master_itemid', '', 'master_itemid')),
+					(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+					(new CButton('button', _('Select')))
+						->addClass(ZBX_STYLE_BTN_GREY)
+						->removeId()
+						->setAttribute('data-hostid', $data['hostid'])
+						->onClick('
+							PopUp("popup.generic", {
+								srctbl: "items",
+								srcfld1: "itemid",
+								srcfld2: "name",
+								dstfrm: "'.$form->getName().'",
+								dstfld1: "master_itemid",
+								dstfld2: "master_itemname",
+								only_hostid: this.dataset.hostid,
+								normal_only: 1
+							}, {dialogue_class: "modal-popup-generic"});
+						'),
+					(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
+					(new CButton('button', _('Select prototype')))
+						->addClass(ZBX_STYLE_BTN_GREY)
+						->removeId()
+						->setAttribute('data-parent_discoveryid', $data['parent_discoveryid'])
+						->onClick('
+							PopUp("popup.generic", {
+								srctbl: "item_prototypes",
+								srcfld1: "itemid",
+								srcfld2: "name",
+								dstfrm: "'.$form->getName().'",
+								dstfld1: "master_itemid",
+								dstfld2: "master_itemname",
+								parent_discoveryid: this.dataset.parent_discoveryid
+							}, {dialogue_class: "modal-popup-generic"});
+						')
+				]
+			]))->setId('master_item-field')
+		);
 	}
-
-	$item_form_list->addRow(
-		(new CVisibilityBox('visible[master_itemid]', 'master_item', _('Original')))->setLabel(_('Master item')),
-		(new CDiv([
-			(new CVar('master_itemname')),
-			$master_item
-		]))->setId('master_item')
-	);
 }
 
 // Append description to form list.
@@ -471,7 +460,7 @@ $item_form_list->addRow(
  */
 $tags_form_list = (new CFormList('tags-form-list'))
 	->addRow(
-		(new CVisibilityBox('visible[tags]', 'tags-div', _('Original')))->setLabel(_('Tags')),
+		(new CVisibilityBox('visible[tags]', 'tags-field', _('Original')))->setLabel(_('Tags')),
 		(new CDiv([
 			(new CRadioButtonList('mass_update_tags', ZBX_ACTION_ADD))
 				->addValue(_('Add'), ZBX_ACTION_ADD)
@@ -482,7 +471,7 @@ $tags_form_list = (new CFormList('tags-form-list'))
 			renderTagTable([['tag' => '', 'value' => '']])
 				->setHeader([_('Name'), _('Value'), _('Action')])
 				->addClass('tags-table')
-		]))->setId('tags-div')
+		]))->setId('tags-field')
 	);
 
 $tabs = (new CTabView())
