@@ -50,26 +50,26 @@ $fields = [
 	'pairs'           => [T_ZBX_STR, O_OPT, P_NO_TRIM|P_ONLY_TD_ARRAY,	null,	null],
 	'steps'           => [null,      O_OPT, P_NO_TRIM|P_ONLY_TD_ARRAY,	null,	'isset({add}) || isset({update})', _('Steps')],
 	'authentication'  => [T_ZBX_INT, O_OPT, null,
-								IN([HTTPTEST_AUTH_NONE, HTTPTEST_AUTH_BASIC, HTTPTEST_AUTH_NTLM, HTTPTEST_AUTH_KERBEROS,
-									HTTPTEST_AUTH_DIGEST
+								IN([ZBX_HTTP_AUTH_NONE, ZBX_HTTP_AUTH_BASIC, ZBX_HTTP_AUTH_NTLM, ZBX_HTTP_AUTH_KERBEROS,
+									ZBX_HTTP_AUTH_DIGEST
 								]),
 								'isset({add}) || isset({update})'
 							],
 	'http_user' =>			[T_ZBX_STR, O_OPT, null,  null,
 								'(isset({add}) || isset({update})) && isset({authentication})'.
-									' && ({authentication}=='.HTTPTEST_AUTH_BASIC.
-										' || {authentication}=='.HTTPTEST_AUTH_NTLM.
-										' || {authentication}=='.HTTPTEST_AUTH_KERBEROS.
-										' || {authentication} == '.HTTPTEST_AUTH_DIGEST.
+									' && ({authentication} == '.ZBX_HTTP_AUTH_BASIC.
+										' || {authentication} == '.ZBX_HTTP_AUTH_NTLM.
+										' || {authentication} == '.ZBX_HTTP_AUTH_KERBEROS.
+										' || {authentication} == '.ZBX_HTTP_AUTH_DIGEST.
 									')',
 								_('User')
 							],
 	'http_password' =>		[T_ZBX_STR, O_OPT, P_NO_TRIM, null,
 								'(isset({add}) || isset({update})) && isset({authentication})'.
-									' && ({authentication}=='.HTTPTEST_AUTH_BASIC.
-										' || {authentication}=='.HTTPTEST_AUTH_NTLM.
-										' || {authentication}=='.HTTPTEST_AUTH_KERBEROS.
-										' || {authentication} == '.HTTPTEST_AUTH_DIGEST.
+									' && ({authentication} == '.ZBX_HTTP_AUTH_BASIC.
+										' || {authentication} == '.ZBX_HTTP_AUTH_NTLM.
+										' || {authentication} == '.ZBX_HTTP_AUTH_KERBEROS.
+										' || {authentication} == '.ZBX_HTTP_AUTH_DIGEST.
 									')',
 								_('Password')
 							],
@@ -186,7 +186,7 @@ elseif (isset($_REQUEST['clone']) && isset($_REQUEST['httptestid'])) {
 elseif (hasRequest('del_history') && hasRequest('httptestid')) {
 	$result = deleteHistoryByHttpTestIds([getRequest('httptestid')]);
 
-	show_messages($result, _('History cleared'), _('Cannot clear history'));
+	show_messages($result, _('History and trends cleared'), _('Cannot clear history and trends'));
 }
 elseif (hasRequest('add') || hasRequest('update')) {
 	if (hasRequest('update')) {
@@ -254,10 +254,10 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'variables' => [],
 			'http_proxy' => $_REQUEST['http_proxy'],
 			'steps' => $steps,
-			'http_user' => ($_REQUEST['authentication'] == HTTPTEST_AUTH_NONE) ? '' : $_REQUEST['http_user'],
-			'http_password' => ($_REQUEST['authentication'] == HTTPTEST_AUTH_NONE) ? '' : $_REQUEST['http_password'],
-			'verify_peer' => getRequest('verify_peer', HTTPTEST_VERIFY_PEER_OFF),
-			'verify_host' => getRequest('verify_host', HTTPTEST_VERIFY_HOST_OFF),
+			'http_user' => $_REQUEST['authentication'] == ZBX_HTTP_AUTH_NONE ? '' : $_REQUEST['http_user'],
+			'http_password' => $_REQUEST['authentication'] == ZBX_HTTP_AUTH_NONE ? '' : $_REQUEST['http_password'],
+			'verify_peer' => getRequest('verify_peer', ZBX_HTTP_VERIFY_PEER_OFF),
+			'verify_host' => getRequest('verify_host', ZBX_HTTP_VERIFY_HOST_OFF),
 			'ssl_cert_file' => getRequest('ssl_cert_file'),
 			'ssl_key_file' => getRequest('ssl_key_file'),
 			'ssl_key_password' => getRequest('ssl_key_password'),
@@ -430,7 +430,7 @@ elseif (hasRequest('action') && getRequest('action') === 'httptest.massclearhist
 		uncheckTableRows(getRequest('hostid'));
 	}
 
-	show_messages($result, _('History cleared'), _('Cannot clear history'));
+	show_messages($result, _('History and trends cleared'), _('Cannot clear history and trends'));
 }
 elseif (hasRequest('action') && getRequest('action') === 'httptest.massdelete'
 		&& hasRequest('group_httptestid') && is_array(getRequest('group_httptestid'))) {
@@ -498,10 +498,6 @@ if (isset($_REQUEST['form'])) {
 		$data['delay'] = $db_httptest['delay'];
 		$data['retries'] = $db_httptest['retries'];
 		$data['status'] = $db_httptest['status'];
-		$data['templates'] = makeHttpTestTemplatesHtml($db_httptest['httptestid'],
-			getHttpTestParentTemplates($db_httptests), CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES)
-		);
-
 		$data['agent'] = ZBX_AGENT_OTHER;
 		$data['agent_other'] = $db_httptest['agent'];
 
@@ -540,7 +536,6 @@ if (isset($_REQUEST['form'])) {
 		$data['http_password'] = $db_httptest['http_password'];
 		$data['http_proxy'] = $db_httptest['http_proxy'];
 		$data['templated'] = (bool) $db_httptest['templateid'];
-
 		$data['verify_peer'] = $db_httptest['verify_peer'];
 		$data['verify_host'] = $db_httptest['verify_host'];
 		$data['ssl_cert_file'] = $db_httptest['ssl_cert_file'];
@@ -608,7 +603,7 @@ if (isset($_REQUEST['form'])) {
 			}
 		}
 
-		$data['authentication'] = getRequest('authentication', HTTPTEST_AUTH_NONE);
+		$data['authentication'] = getRequest('authentication', ZBX_HTTP_AUTH_NONE);
 		$data['http_user'] = getRequest('http_user', '');
 		$data['http_password'] = getRequest('http_password', '');
 		$data['http_proxy'] = getRequest('http_proxy', '');
@@ -641,6 +636,10 @@ if (isset($_REQUEST['form'])) {
 	}
 
 	if ($db_httptest) {
+		$data['templates'] = makeHttpTestTemplatesHtml($db_httptest['httptestid'],
+			getHttpTestParentTemplates($db_httptests), CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES)
+		);
+
 		$parent_templates = getHttpTestParentTemplates($db_httptests)['templates'];
 
 		$rw_templates = $data['host']['parentTemplates']
@@ -757,7 +756,7 @@ else {
 	}
 
 	// Get host groups.
-	$filter_groupids = getSubGroups($filter_groupids, $filter['groups'], ['editable' => true], $data['context']);
+	$filter_groupids = getSubGroups($filter_groupids, $filter['groups'], $data['context']);
 
 	if ($data['context'] === 'host') {
 		$filter['hosts'] = $filter_hostids
