@@ -606,6 +606,11 @@ class CHost extends CHostGeneral {
 			unset($sqlParts['select'][$upcased_index]);
 		}
 
+		if (!$options['countOutput'] && $this->outputIsRequested('inventory_mode', $options['output'])) {
+			$sqlParts['select']['inventory_mode'] =
+				dbConditionCoalesce('hinv.inventory_mode', HOST_INVENTORY_DISABLED, 'inventory_mode');
+		}
+
 		if ((!$options['countOutput'] && $this->outputIsRequested('inventory_mode', $options['output']))
 				|| ($options['filter'] && array_key_exists('inventory_mode', $options['filter']))) {
 			$sqlParts['left_join'][] = ['alias' => 'hinv', 'table' => 'host_inventory', 'using' => 'hostid'];
@@ -1490,24 +1495,29 @@ class CHost extends CHostGeneral {
 		}
 
 		// delete the items
-		$del_items = API::Item()->get([
-			'output' => [],
-			'templateids' => $hostids,
-			'nopermissions' => true,
+		$db_items = DB::select('items', [
+			'output' => ['itemid', 'name'],
+			'filter' => [
+				'hostid' => $hostids,
+				'flags' => ZBX_FLAG_DISCOVERY_NORMAL,
+				'type' => CItem::SUPPORTED_ITEM_TYPES
+			],
 			'preservekeys' => true
 		]);
-		if ($del_items) {
-			CItemManager::delete(array_keys($del_items));
+
+		if ($db_items) {
+			CItem::deleteForce($db_items);
 		}
 
-		// delete web tests
-		$delHttptests = [];
-		$dbHttptests = get_httptests_by_hostid($hostids);
-		while ($dbHttptest = DBfetch($dbHttptests)) {
-			$delHttptests[$dbHttptest['httptestid']] = $dbHttptest['httptestid'];
-		}
-		if (!empty($delHttptests)) {
-			API::HttpTest()->delete($delHttptests, true);
+		// delete web scenarios
+		$db_httptests = DB::select('httptest', [
+			'output' => ['httptestid', 'name'],
+			'filter' => ['hostid' => $hostids],
+			'preservekeys' => true
+		]);
+
+		if ($db_httptests) {
+			CHttpTest::deleteForce($db_httptests);
 		}
 
 		// delete host from maps
@@ -1523,7 +1533,7 @@ class CHost extends CHostGeneral {
 		$actionids = [];
 		$sql = 'SELECT DISTINCT actionid'.
 				' FROM conditions'.
-				' WHERE conditiontype='.CONDITION_TYPE_HOST.
+				' WHERE conditiontype='.ZBX_CONDITION_TYPE_HOST.
 				' AND '.dbConditionString('value', $hostids);
 		$dbActions = DBselect($sql);
 		while ($dbAction = DBfetch($dbActions)) {
@@ -1551,7 +1561,7 @@ class CHost extends CHostGeneral {
 
 		// delete action conditions
 		DB::delete('conditions', [
-			'conditiontype' => CONDITION_TYPE_HOST,
+			'conditiontype' => ZBX_CONDITION_TYPE_HOST,
 			'value' => $hostids
 		]);
 
@@ -1886,7 +1896,7 @@ class CHost extends CHostGeneral {
 	 *
 	 * @param array  $hosts
 	 * @param string $hosts[]['hostid']                    (optional if $db_hosts is null)
-	 * @param int    $hosts[]['tls_connect']               (optionsl)
+	 * @param int    $hosts[]['tls_connect']               (optional)
 	 * @param int    $hosts[]['tls_accept']                (optional)
 	 * @param string $hosts[]['tls_psk_identity']          (optional)
 	 * @param string $hosts[]['tls_psk']                   (optional)
