@@ -362,11 +362,13 @@ class CTemplate extends CHostGeneral {
 	 * @throws APIException if the input is invalid.
 	 */
 	protected function validateCreate(array &$templates) {
-		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['host'], ['name']], 'fields' => [
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['uuid'], ['host'], ['name']], 'fields' => [
 			'uuid' =>			['type' => API_UUID],
 			'host' =>			['type' => API_H_NAME, 'flags' => API_REQUIRED, 'length' => DB::getFieldLength('hosts', 'host')],
 			'name' =>			['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('hosts', 'name'), 'default_source' => 'host'],
 			'description' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'description')],
+			'vendor_name' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_name')],
+			'vendor_version' =>	['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_version')],
 			'groups' =>			['type' => API_OBJECTS, 'flags' => API_REQUIRED | API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid']], 'fields' => [
 				'groupid' =>		['type' => API_ID, 'flags' => API_REQUIRED]
 			]],
@@ -392,37 +394,69 @@ class CTemplate extends CHostGeneral {
 			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		$this->checkGroups($templates);
-		$this->checkDuplicates($templates);
-		self::checkAndAddUuid($templates);
+		self::checkVendorFields($templates);
 
+		self::addUuid($templates);
+
+		self::checkUuidDuplicates($templates);
+		$this->checkDuplicates($templates);
+		$this->checkGroups($templates);
 		$this->checkTemplates($templates);
 	}
 
 	/**
-	 * Check that no duplicate UUID is being added. Add UUID to all templates, if it doesn't exist.
+	 * Add the UUID to those of the given templates that don't have the 'uuid' parameter set.
 	 *
-	 * @param array $templates_to_create
-	 *
-	 * @throws APIException
+	 * @param array $templates
 	 */
-	private static function checkAndAddUuid(array &$templates_to_create): void {
-		foreach ($templates_to_create as &$template) {
+	private static function addUuid(array &$templates): void {
+		foreach ($templates as &$template) {
 			if (!array_key_exists('uuid', $template)) {
 				$template['uuid'] = generateUuidV4();
 			}
 		}
 		unset($template);
+	}
 
-		$db_uuid = DB::select('hosts', [
+	/**
+	 * Verify template UUIDs are not repeated.
+	 *
+	 * @param array      $templates
+	 * @param array|null $db_templates
+	 *
+	 * @throws APIException
+	 */
+	private static function checkUuidDuplicates(array $templates, array $db_templates = null): void {
+		$template_indexes = [];
+
+		foreach ($templates as $i => $template) {
+			if (!array_key_exists('uuid', $template)) {
+				continue;
+			}
+
+			if ($db_templates === null || $template['uuid'] !== $db_templates[$template['templateid']]['uuid']) {
+				$template_indexes[$template['uuid']] = $i;
+			}
+		}
+
+		if (!$template_indexes) {
+			return;
+		}
+
+		$duplicates = DB::select('hosts', [
 			'output' => ['uuid'],
-			'filter' => ['uuid' => array_column($templates_to_create, 'uuid')],
+			'filter' => [
+				'status' => HOST_STATUS_TEMPLATE,
+				'uuid' => array_keys($template_indexes)
+			],
 			'limit' => 1
 		]);
 
-		if ($db_uuid) {
+		if ($duplicates) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('Entry with UUID "%1$s" already exists.', $db_uuid[0]['uuid'])
+				_s('Invalid parameter "%1$s": %2$s.', '/'.($template_indexes[$duplicates[0]['uuid']] + 1),
+					_('template with the same UUID already exists')
+				)
 			);
 		}
 	}
@@ -469,12 +503,14 @@ class CTemplate extends CHostGeneral {
 	 * @throws APIException if the input is invalid.
 	 */
 	protected function validateUpdate(array &$templates, array &$db_templates = null) {
-		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['templateid'], ['host'], ['name']], 'fields' => [
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['uuid'], ['templateid'], ['host'], ['name']], 'fields' => [
 			'uuid' => 				['type' => API_UUID],
 			'templateid' =>			['type' => API_ID, 'flags' => API_REQUIRED],
 			'host' =>				['type' => API_H_NAME, 'length' => DB::getFieldLength('hosts', 'host')],
 			'name' =>				['type' => API_STRING_UTF8, 'flags' => API_NOT_EMPTY, 'length' => DB::getFieldLength('hosts', 'name')],
 			'description' =>		['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'description')],
+			'vendor_name' =>		['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_name')],
+			'vendor_version' =>		['type' => API_STRING_UTF8, 'length' => DB::getFieldLength('hosts', 'vendor_version')],
 			'groups' =>				['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid']], 'fields' => [
 				'groupid' =>			['type' => API_ID, 'flags' => API_REQUIRED]
 			]],
@@ -502,7 +538,7 @@ class CTemplate extends CHostGeneral {
 		}
 
 		$db_templates = $this->get([
-			'output' => ['templateid', 'host', 'name', 'description'],
+			'output' => ['uuid', 'templateid', 'host', 'name', 'description', 'vendor_name', 'vendor_version'],
 			'templateids' => array_column($templates, 'templateid'),
 			'editable' => true,
 			'preservekeys' => true
@@ -514,6 +550,8 @@ class CTemplate extends CHostGeneral {
 
 		$this->addAffectedObjects($templates, $db_templates);
 
+		self::checkVendorFields($templates, $db_templates);
+		self::checkUuidDuplicates($templates, $db_templates);
 		$this->checkDuplicates($templates, $db_templates);
 		$this->checkGroups($templates, $db_templates);
 		$this->checkTemplates($templates, $db_templates);
@@ -521,6 +559,39 @@ class CTemplate extends CHostGeneral {
 		$templates = $this->validateHostMacros($templates, $db_templates);
 	}
 
+	/**
+	 * Check vendor fields for update or create operation.
+	 *
+	 * @param array      $templates
+	 * @param array|null $db_templates
+	 *
+	 * @throws Exception
+	 */
+	private static function checkVendorFields(array $templates, array $db_templates = null): void {
+		$vendor_fields = array_fill_keys(['vendor_name', 'vendor_version'], '');
+
+		foreach ($templates as $i => $template) {
+			if (!array_key_exists('vendor_name', $template) && !array_key_exists('vendor_version', $template)) {
+				continue;
+			}
+
+			$_template = array_intersect_key($template, $vendor_fields);
+
+			if ($db_templates === null) {
+				$_template += $vendor_fields;
+			}
+			else {
+				$_template += array_intersect_key($db_templates[$template['templateid']], $vendor_fields);
+			}
+
+			if (($_template['vendor_name'] === '') !== ($_template['vendor_version'] === '')) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _s('Invalid parameter "%1$s": %2$s.', '/'.($i + 1),
+					_('both vendor_name and vendor_version should be either present or empty')
+				));
+			}
+		}
+	}
+
 	/**
 	 * Delete template.
 	 *
@@ -541,19 +612,24 @@ class CTemplate extends CHostGeneral {
 			'nopermissions' => true,
 			'preservekeys' => true
 		]);
+
 		if ($del_rules) {
 			CDiscoveryRuleManager::delete(array_keys($del_rules));
 		}
 
 		// delete the items
-		$del_items = API::Item()->get([
-			'output' => [],
-			'templateids' => $templateids,
-			'nopermissions' => true,
+		$db_items = DB::select('items', [
+			'output' => ['itemid', 'name'],
+			'filter' => [
+				'hostid' => $templateids,
+				'flags' => ZBX_FLAG_DISCOVERY_NORMAL,
+				'type' => CItem::SUPPORTED_ITEM_TYPES
+			],
 			'preservekeys' => true
 		]);
-		if ($del_items) {
-			CItemManager::delete(array_keys($del_items));
+
+		if ($db_items) {
+			CItem::deleteForce($db_items);
 		}
 
 		// delete host from maps
@@ -566,7 +642,7 @@ class CTemplate extends CHostGeneral {
 		$actionids = [];
 		$sql = 'SELECT DISTINCT actionid'.
 			' FROM conditions'.
-			' WHERE conditiontype='.CONDITION_TYPE_TEMPLATE.
+			' WHERE conditiontype='.ZBX_CONDITION_TYPE_TEMPLATE.
 			' AND '.dbConditionString('value', $templateids);
 		$dbActions = DBselect($sql);
 		while ($dbAction = DBfetch($dbActions)) {
@@ -592,7 +668,7 @@ class CTemplate extends CHostGeneral {
 
 		// delete action conditions
 		DB::delete('conditions', [
-			'conditiontype' => CONDITION_TYPE_TEMPLATE,
+			'conditiontype' => ZBX_CONDITION_TYPE_TEMPLATE,
 			'value' => $templateids
 		]);
 
@@ -625,15 +701,15 @@ class CTemplate extends CHostGeneral {
 			'operationid'=>$delOperationids
 		]);
 
-		// http tests
-		$delHttpTests = API::HttpTest()->get([
-			'templateids' => $templateids,
-			'output' => ['httptestid'],
-			'nopermissions' => 1,
+		// delete web scenarios
+		$db_httptests = DB::select('httptest', [
+			'output' => ['httptestid', 'name'],
+			'filter' => ['hostid' => $templateids],
 			'preservekeys' => true
 		]);
-		if (!empty($delHttpTests)) {
-			API::HttpTest()->delete(array_keys($delHttpTests), true);
+
+		if ($db_httptests) {
+			CHttpTest::deleteForce($db_httptests);
 		}
 
 		// Get host prototype operations from LLD overrides where this template is linked.
