@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2023 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -47,12 +47,20 @@ class CConfigurationExport {
 
 	protected $options;
 
+	/**
+	 * Array with templates to be unlinked entity data.
+	 *
+	 * @var array
+	 */
+	protected $unlink_templates_data;
+
 	/**
 	 * Constructor.
 	 *
-	 * @param array $options IDs of elements that should be exported.
+	 * @param array $options                IDs of elements that should be exported.
+	 * @param array $unlink_templates_data  Template IDs with parent template ids that should be unlinked.
 	 */
-	public function __construct(array $options) {
+	public function __construct(array $options, array $unlink_templates_data = []) {
 		$this->options = array_merge([
 			'hosts' => [],
 			'templates' => [],
@@ -63,6 +71,59 @@ class CConfigurationExport {
 			'mediaTypes' => []
 		], $options);
 
+		$this->unlink_templates_data = $unlink_templates_data;
+
+		if ($this->unlink_templates_data) {
+			$unlink_templateids = [];
+
+			$unlink_templates_data_keys = ['unlink_itemids', 'unlink_discoveries', 'unlink_httptests',
+				'unlink_graphs', 'unlink_triggers'
+			];
+
+			foreach ($this->unlink_templates_data as &$template_data) {
+				$unlink_templateids = array_merge($unlink_templateids, $template_data['unlink_templateids']);
+
+				foreach ($unlink_templates_data_keys as $data_key) {
+					$template_data[$data_key] = [];
+				}
+			}
+			unset($template_data);
+
+			$unlink_templates_entities = API::Template()->get([
+				'output' => [],
+				'selectItems' => ['itemid'],
+				'selectDiscoveries' => ['itemid'],
+				'selectHttpTests' => ['httptestid'],
+				'selectGraphs' => ['graphid'],
+				'selectTriggers' => ['triggerid'],
+				'templateids' => $unlink_templateids,
+				'preservekeys' => true
+			]);
+
+			foreach ($unlink_templates_entities as $template_entity) {
+				foreach ($this->unlink_templates_data as &$template_data) {
+					if (in_array($template_entity['templateid'], $template_data['unlink_templateids'])) {
+						$template_data['unlink_itemids'] = array_merge($template_data['unlink_itemids'],
+							array_column($template_entity['items'], 'itemid')
+						);
+						$template_data['unlink_discoveries'] = array_merge($template_data['unlink_discoveries'],
+							array_column($template_entity['discoveries'], 'itemid')
+						);
+						$template_data['unlink_httptests'] = array_merge($template_data['unlink_httptests'],
+							array_column($template_entity['httpTests'], 'httptestid')
+						);
+						$template_data['unlink_graphs'] = array_merge($template_data['unlink_graphs'],
+							array_column($template_entity['graphs'], 'graphid')
+						);
+						$template_data['unlink_triggers'] = array_merge($template_data['unlink_triggers'],
+							array_column($template_entity['triggers'], 'triggerid')
+						);
+					}
+				}
+				unset($template_data);
+			}
+		}
+
 		$this->data = [
 			'template_groups' => [],
 			'host_groups' => [],
@@ -101,6 +162,18 @@ class CConfigurationExport {
 				'status_codes', 'follow_redirects', 'post_type', 'http_proxy', 'headers', 'retrieve_mode',
 				'request_method', 'output_format', 'ssl_cert_file', 'ssl_key_file', 'ssl_key_password', 'verify_peer',
 				'verify_host', 'allow_traps', 'discover', 'uuid'
+			],
+			'trigger_prototype' => ['expression', 'description', 'url', 'url_name', 'status', 'priority', 'comments',
+				'type', 'flags', 'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag',
+				'manual_close', 'opdata', 'discover', 'event_name', 'uuid'
+			],
+			'httptests' => ['name', 'hostid', 'delay', 'retries', 'agent', 'http_proxy', 'variables',
+				'headers', 'status', 'authentication', 'http_user', 'http_password', 'verify_peer', 'verify_host',
+				'ssl_cert_file', 'ssl_key_file', 'ssl_key_password', 'uuid'
+			],
+			'trigger' => ['expression', 'description', 'url', 'url_name', 'status', 'priority', 'comments', 'type',
+				'flags', 'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag', 'manual_close',
+				'opdata', 'event_name', 'uuid'
 			]
 		];
 	}
@@ -141,7 +214,15 @@ class CConfigurationExport {
 
 			$simple_triggers = [];
 			if ($this->data['triggers']) {
-				$simple_triggers = $this->builder->extractSimpleTriggers($this->data['triggers']);
+				$unlink_itemids = [];
+
+				if ($this->unlink_templates_data) {
+					foreach ($this->unlink_templates_data as $template_data) {
+						$unlink_itemids = array_merge($unlink_itemids, $template_data['unlink_itemids']);
+					}
+				}
+
+				$simple_triggers = $this->builder->extractSimpleTriggers($this->data['triggers'], $unlink_itemids);
 			}
 
 			if ($this->data['template_groups']) {
@@ -312,7 +393,7 @@ class CConfigurationExport {
 	 */
 	protected function gatherTemplates(array $templateids) {
 		$templates = API::Template()->get([
-			'output' => ['host', 'name', 'description', 'uuid'],
+			'output' => ['host', 'name', 'description', 'uuid', 'vendor_name', 'vendor_version'],
 			'selectTemplateGroups' => ['groupid', 'name', 'uuid'],
 			'selectParentTemplates' => API_OUTPUT_EXTEND,
 			'selectMacros' => API_OUTPUT_EXTEND,
@@ -339,6 +420,7 @@ class CConfigurationExport {
 			$templates = $this->gatherItems($templates);
 			$templates = $this->gatherDiscoveryRules($templates);
 			$templates = $this->gatherHttpTests($templates);
+			$templates = $this->removeHttpTestItems($templates);
 		}
 
 		$this->data['templates'] = $templates;
@@ -381,6 +463,7 @@ class CConfigurationExport {
 			$hosts = $this->gatherItems($hosts);
 			$hosts = $this->gatherDiscoveryRules($hosts);
 			$hosts = $this->gatherHttpTests($hosts);
+			$hosts = $this->removeHttpTestItems($hosts);
 		}
 
 		$this->data['hosts'] = $hosts;
@@ -522,16 +605,53 @@ class CConfigurationExport {
 	 * @return array
 	 */
 	protected function gatherItems(array $hosts) {
-		$items = API::Item()->get([
-			'output' => $this->dataFields['item'],
+		$options = [
 			'selectPreprocessing' => ['type', 'params', 'error_handler', 'error_handler_params'],
 			'selectTags' => ['tag', 'value'],
-			'hostids' => array_keys($hosts),
-			'inherited' => false,
 			'webitems' => true,
 			'filter' => ['flags' => ZBX_FLAG_DISCOVERY_NORMAL],
 			'preservekeys' => true
-		]);
+		];
+
+		// Find inherited template items.
+		$inherited_items = [];
+
+		if ($this->unlink_templates_data) {
+			$templateids = [];
+
+			foreach ($this->unlink_templates_data as $unlink_template_data) {
+				if ($unlink_template_data['unlink_itemids']) {
+					$templateids[] = $unlink_template_data['templateid'];
+				}
+			}
+
+			$inherit_options = [
+				'output' => array_merge($this->dataFields['item'], ['templateid']),
+				'templateids' => $templateids,
+				'inherited' => true
+			];
+
+			$inherited_items = API::Item()->get($options + $inherit_options);
+
+			foreach ($inherited_items as $itemid => $item) {
+				foreach ($this->unlink_templates_data as $templates_data) {
+					if($item['hostid'] == $templates_data['templateid']
+							&& !in_array($item['templateid'], $templates_data['unlink_itemids'])) {
+						unset($inherited_items[$itemid]);
+					}
+				}
+			}
+		}
+
+		$options += [
+			'output' => $this->dataFields['item'],
+			'hostids' => array_keys($hosts),
+			'inherited' => false
+		];
+
+		$items = API::Item()->get($options);
+
+		$items = $items + $inherited_items;
 
 		foreach ($items as $itemid => &$item) {
 			if ($item['type'] == ITEM_TYPE_DEPENDENT) {
@@ -546,11 +666,7 @@ class CConfigurationExport {
 		}
 		unset($item);
 
-		foreach ($items as $itemid => $item) {
-			if ($item['type'] == ITEM_TYPE_HTTPTEST) {
-				unset($items[$itemid]);
-			}
-		}
+		// Web items will be removed from result after all items and discovery rules are gathered and processed.
 
 		$items = $this->prepareItems($items);
 
@@ -603,34 +719,70 @@ class CConfigurationExport {
 	 * @return array
 	 */
 	protected function gatherDiscoveryRules(array $hosts) {
-		$discovery_rules = API::DiscoveryRule()->get([
-			'output' => $this->dataFields['drule'],
+		$options = [
 			'selectFilter' => ['evaltype', 'formula', 'conditions'],
 			'selectLLDMacroPaths' => ['lld_macro', 'path'],
 			'selectPreprocessing' => ['type', 'params', 'error_handler', 'error_handler_params'],
 			'selectOverrides' => ['name', 'step', 'stop', 'filter', 'operations'],
-			'hostids' => array_keys($hosts),
-			'inherited' => false,
 			'preservekeys' => true
-		]);
+		];
+		// Find inherited discovery rules.
+		$inherited_discovery_rules = [];
+
+		if ($this->unlink_templates_data) {
+			$templateids = [];
+
+			foreach ($this->unlink_templates_data as $unlink_template_data) {
+				if ($unlink_template_data['unlink_discoveries']) {
+					$templateids[] = $unlink_template_data['templateid'];
+				}
+			}
+
+			$inherit_options = [
+				'output' => array_merge($this->dataFields['drule'], ['templateid']),
+				'templateids' => $templateids,
+				'inherited' => true
+			];
+
+			$inherited_discovery_rules = API::DiscoveryRule()->get($options + $inherit_options);
+
+			foreach ($inherited_discovery_rules as $id => $discovery_rule) {
+				foreach ($this->unlink_templates_data as $templates_data) {
+					if($discovery_rule['hostid'] == $templates_data['templateid']
+							&& !in_array($discovery_rule['templateid'], $templates_data['unlink_discoveries'])) {
+						unset($discovery_rule[$id]);
+					}
+				}
+			}
+		}
+
+		$options += [
+			'output' => $this->dataFields['drule'],
+			'hostids' => array_keys($hosts),
+			'inherited' => false
+		];
+
+		$discovery_rules = API::DiscoveryRule()->get($options);
+
+		$discovery_rules = $discovery_rules + $inherited_discovery_rules;
 
 		$itemids = [];
 		foreach ($hosts as $host_data) {
 			foreach ($host_data['items'] as $item) {
 				$itemids[$item['itemid']] = $item['key_'];
 			}
-		};
+		}
 
 		$discovery_rules = $this->prepareDiscoveryRules($discovery_rules);
 
+		// Discovery rules may use web items as master items.
 		foreach ($discovery_rules as $discovery_rule) {
 			if ($discovery_rule['type'] == ITEM_TYPE_DEPENDENT) {
-				if (!array_key_exists($discovery_rule['master_itemid'], $itemids)) {
-					// Do not export dependent discovery rule with master item from template.
-					continue;
-				}
+				$master_itemid = $discovery_rule['master_itemid'];
 
-				$discovery_rule['master_item'] = ['key_' => $itemids[$discovery_rule['master_itemid']]];
+				if (array_key_exists($master_itemid, $itemids)) {
+					$discovery_rule['master_item'] = ['key_' => $itemids[$master_itemid]];
+				}
 			}
 
 			foreach ($discovery_rule['itemPrototypes'] as $itemid => $item_prototype) {
@@ -668,13 +820,6 @@ class CConfigurationExport {
 			// Unset unnecessary filter field and prepare the operations.
 			if ($item['overrides']) {
 				foreach ($item['overrides'] as &$override) {
-					if (array_key_exists('filter', $override)) {
-						if (!$override['filter']['conditions']) {
-							unset($override['filter']);
-						}
-						unset($override['filter']['eval_formula']);
-					}
-
 					foreach ($override['operations'] as &$operation) {
 						if (array_key_exists('opstatus', $operation)) {
 							$operation['status'] = $operation['opstatus']['status'];
@@ -752,15 +897,18 @@ class CConfigurationExport {
 		}
 
 		// gather item prototypes
-		$item_prototypes = API::ItemPrototype()->get([
+		$options = [
 			'output' => $this->dataFields['item_prototype'],
 			'selectDiscoveryRule' => ['itemid'],
 			'selectPreprocessing' => ['type', 'params', 'error_handler', 'error_handler_params'],
 			'selectTags' => ['tag', 'value'],
-			'discoveryids' => zbx_objectValues($items, 'itemid'),
-			'inherited' => false,
+			'discoveryids' => array_column($items, 'itemid'),
 			'preservekeys' => true
-		]);
+		];
+
+		$options +=  $this->unlink_templates_data ? ['templated' => true] : ['inherited' => false];
+
+		$item_prototypes = API::ItemPrototype()->get($options);
 
 		$unresolved_master_itemids = [];
 
@@ -823,14 +971,17 @@ class CConfigurationExport {
 		}
 
 		// gather graph prototypes
-		$graphs = API::GraphPrototype()->get([
-			'discoveryids' => zbx_objectValues($items, 'itemid'),
+		$options = [
+			'output' => API_OUTPUT_EXTEND,
+			'discoveryids' => array_column($items, 'itemid'),
 			'selectDiscoveryRule' => API_OUTPUT_EXTEND,
 			'selectGraphItems' => API_OUTPUT_EXTEND,
-			'output' => API_OUTPUT_EXTEND,
-			'inherited' => false,
 			'preservekeys' => true
-		]);
+		];
+
+		$options +=  $this->unlink_templates_data ? ['templated' => true] : ['inherited' => false];
+
+		$graphs = API::GraphPrototype()->get($options);
 
 		$graphs = $this->prepareGraphs($graphs);
 
@@ -839,20 +990,20 @@ class CConfigurationExport {
 		}
 
 		// gather trigger prototypes
-		$triggers = API::TriggerPrototype()->get([
-			'output' => ['expression', 'description', 'url', 'status', 'priority', 'comments', 'type', 'flags',
-				'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag', 'manual_close', 'opdata',
-				'discover', 'event_name', 'uuid'
-			],
+		$options = [
+			'output' => $this->dataFields['trigger_prototype'],
 			'selectDiscoveryRule' => API_OUTPUT_EXTEND,
 			'selectDependencies' => ['expression', 'description', 'recovery_expression'],
 			'selectHosts' => ['status'],
 			'selectItems' => ['itemid', 'flags', 'type'],
 			'selectTags' => ['tag', 'value'],
 			'discoveryids' => zbx_objectValues($items, 'itemid'),
-			'inherited' => false,
 			'preservekeys' => true
-		]);
+		];
+
+		$options +=  $this->unlink_templates_data ? ['templated' => true] : ['inherited' => false];
+
+		$triggers = API::TriggerPrototype()->get($options);
 
 		$triggers = $this->prepareTriggers($triggers);
 
@@ -861,7 +1012,7 @@ class CConfigurationExport {
 		}
 
 		// gather host prototypes
-		$host_prototypes = API::HostPrototype()->get([
+		$options = [
 			'discoveryids' => zbx_objectValues($items, 'itemid'),
 			'output' => API_OUTPUT_EXTEND,
 			'selectGroupLinks' => ['groupid'],
@@ -871,9 +1022,14 @@ class CConfigurationExport {
 			'selectMacros' => API_OUTPUT_EXTEND,
 			'selectTags' => ['tag', 'value'],
 			'selectInterfaces' => ['main', 'type', 'useip', 'ip', 'dns', 'port', 'details'],
-			'inherited' => false,
 			'preservekeys' => true
-		]);
+		];
+
+		if (!$this->unlink_templates_data) {
+			$options += ['inherited' => false];
+		}
+
+		$host_prototypes = API::HostPrototype()->get($options);
 
 		// Replace group prototype group IDs with references.
 		$groupids = [];
@@ -907,19 +1063,53 @@ class CConfigurationExport {
 	 * @return array
 	 */
 	protected function gatherHttpTests(array $hosts) {
-		$httptests = API::HttpTest()->get([
-			'output' => ['name', 'hostid', 'delay', 'retries', 'agent', 'http_proxy', 'variables',
-				'headers', 'status', 'authentication', 'http_user', 'http_password', 'verify_peer', 'verify_host',
-				'ssl_cert_file', 'ssl_key_file', 'ssl_key_password', 'uuid'
-			],
+		$options = [
 			'selectSteps' => ['no', 'name', 'url', 'query_fields', 'posts', 'variables', 'headers', 'follow_redirects',
 				'retrieve_mode', 'timeout', 'required', 'status_codes'
 			],
 			'selectTags' => ['tag', 'value'],
-			'hostids' => array_keys($hosts),
-			'inherited' => false,
 			'preservekeys' => true
-		]);
+		];
+
+		// Get inherited templates http tests.
+		$inherited_httptests = [];
+
+		if ($this->unlink_templates_data) {
+			$templateids = [];
+
+			foreach ($this->unlink_templates_data as $unlink_template_data) {
+				if ($unlink_template_data['unlink_httptests']) {
+					$templateids[] = $unlink_template_data['templateid'];
+				}
+			}
+
+			$inherit_options = [
+				'output' => array_merge($this->dataFields['httptests'], ['templateid']),
+				'templateids' => $templateids,
+				'inherited' => true
+			];
+
+			$inherited_httptests = API::HttpTest()->get($options + $inherit_options);
+
+			foreach ($inherited_httptests as $id => $httptest) {
+				foreach ($this->unlink_templates_data as $templates_data) {
+					if($httptest['hostid'] == $templates_data['templateid']
+							&& !in_array($httptest['templateid'], $templates_data['unlink_httptests'])) {
+						unset($inherited_httptests[$id]);
+					}
+				}
+			}
+		}
+
+		$options += [
+			'output' => $this->dataFields['httptests'],
+			'hostids' => array_keys($hosts),
+			'inherited' => false
+		];
+
+		$httptests = API::HttpTest()->get($options);
+
+		$httptests += $inherited_httptests;
 
 		foreach ($httptests as $httptest) {
 			$hosts[$httptest['hostid']]['httptests'][] = $httptest;
@@ -935,16 +1125,51 @@ class CConfigurationExport {
 	 * @param array $templateIds
 	 */
 	protected function gatherGraphs(array $hostIds, array $templateIds) {
-		$hostIds = array_merge($hostIds, $templateIds);
-
-		$graphs = API::Graph()->get([
-			'hostids' => $hostIds,
+		$options = [
 			'filter' => ['flags' => ZBX_FLAG_DISCOVERY_NORMAL],
 			'selectGraphItems' => API_OUTPUT_EXTEND,
-			'inherited' => false,
 			'output' => API_OUTPUT_EXTEND,
 			'preservekeys' => true
-		]);
+		];
+
+		// Get inherited template graphs.
+		$inherited_graphs = [];
+
+		if ($this->unlink_templates_data) {
+			$templateids = [];
+
+			foreach ($this->unlink_templates_data as $unlink_template_data) {
+				if ($unlink_template_data['unlink_graphs']) {
+					$templateids[] = $unlink_template_data['templateid'];
+				}
+			}
+
+			$inherit_options = [
+				'selectHosts' => ['hostid'],
+				'templateids' => $templateids,
+				'inherited' => true
+			];
+
+			$inherited_graphs = API::Graph()->get($options + $inherit_options);
+
+			foreach ($inherited_graphs as $id => $graph) {
+				foreach ($this->unlink_templates_data as $templates_data) {
+					if(in_array($templates_data['templateid'], $graph['hosts'])
+							&& !in_array($graph['templateid'], $templates_data['unlink_graphs'])) {
+						unset($inherited_graphs[$id]);
+					}
+				}
+			}
+		}
+
+		$options += [
+			'hostids' => array_merge($hostIds, $templateIds),
+			'inherited' => false
+		];
+
+		$graphs = API::Graph()->get($options);
+
+		$graphs += $inherited_graphs;
 
 		$this->data['graphs'] = $this->prepareGraphs($graphs);
 	}
@@ -1043,22 +1268,54 @@ class CConfigurationExport {
 	 * @param array $templateIds
 	 */
 	protected function gatherTriggers(array $hostIds, array $templateIds) {
-		$hostIds = array_merge($hostIds, $templateIds);
-
-		$triggers = API::Trigger()->get([
-			'output' => ['expression', 'description', 'url', 'status', 'priority', 'comments', 'type', 'flags',
-				'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag', 'manual_close', 'opdata',
-				'event_name', 'uuid'
-			],
+		$options = [
 			'selectDependencies' => ['expression', 'description', 'recovery_expression'],
 			'selectItems' => ['itemid', 'flags', 'type', 'templateid'],
 			'selectTags' => ['tag', 'value'],
 			'selectHosts' => ['status'],
-			'hostids' => $hostIds,
 			'filter' => ['flags' => ZBX_FLAG_DISCOVERY_NORMAL],
-			'inherited' => false,
 			'preservekeys' => true
-		]);
+		];
+
+		// Get templates inherited triggers.
+		$inherited_triggers = [];
+
+		if ($this->unlink_templates_data) {
+			$templateids = [];
+
+			foreach ($this->unlink_templates_data as $unlink_template_data) {
+				if ($unlink_template_data['unlink_triggers']) {
+					$templateids[] = $unlink_template_data['templateid'];
+				}
+			}
+
+			$inherit_options = [
+				'output' => array_merge($this->dataFields['trigger'], ['templateid']),
+				'templateids' => $templateids,
+				'inherited' => true
+			];
+
+			$inherited_triggers = API::Trigger()->get($options + $inherit_options);
+
+			foreach ($inherited_triggers as $id => $trigger) {
+				foreach ($this->unlink_templates_data as $templates_data) {
+					if(in_array($templates_data['templateid'], $trigger['hosts'])
+							&& !in_array($trigger['templateid'], $templates_data['unlink_triggers'])) {
+						unset($inherited_triggers[$id]);
+					}
+				}
+			}
+		}
+
+		$options += [
+			'output' => $this->dataFields['trigger'],
+			'hostids' => array_merge($hostIds, $templateIds),
+			'inherited' => false
+		];
+
+		$triggers = API::Trigger()->get($options);
+
+		$triggers += $inherited_triggers;
 
 		$this->data['triggers'] = $this->prepareTriggers($triggers);
 	}
@@ -1139,9 +1396,9 @@ class CConfigurationExport {
 		$this->data['mediaTypes'] = API::MediaType()->get([
 			'output' => ['name', 'type', 'smtp_server', 'smtp_port', 'smtp_helo', 'smtp_email', 'smtp_security',
 				'smtp_verify_peer', 'smtp_verify_host', 'smtp_authentication', 'username', 'passwd', 'content_type',
-				'exec_path', 'exec_params', 'gsm_modem', 'status', 'maxsessions', 'maxattempts', 'attempt_interval',
-				'script', 'timeout', 'process_tags', 'show_event_menu', 'event_menu_url', 'event_menu_name',
-				'description', 'parameters'
+				'exec_path', 'gsm_modem', 'status', 'maxsessions', 'maxattempts', 'attempt_interval', 'script',
+				'timeout', 'process_tags', 'show_event_menu', 'event_menu_url', 'event_menu_name', 'description',
+				'parameters', 'provider'
 			],
 			'selectMessageTemplates' => ['eventsource', 'recovery', 'subject', 'message'],
 			'mediatypeids' => $mediatypeids,
@@ -1384,8 +1641,8 @@ class CConfigurationExport {
 			$host = reset($graph['hosts']);
 
 			$ids[$id] = [
-				'name' => $graph['name'],
-				'host' => $host['host']
+				'host' => $host['host'],
+				'name' => $graph['name']
 			];
 		}
 
@@ -1420,8 +1677,8 @@ class CConfigurationExport {
 			$host = reset($item['hosts']);
 
 			$ids[$id] = [
-				'key' => $item['key_'],
-				'host' => $host['host']
+				'host' => $host['host'],
+				'key' => $item['key_']
 			];
 		}
 
@@ -1491,4 +1748,26 @@ class CConfigurationExport {
 
 		return $ids;
 	}
+
+	/**
+	 * Remove web items.
+	 *
+	 * @param array $hosts  Array of hosts or templates to remove the web items from.
+	 *
+	 * @return array
+	 */
+	protected function removeHttpTestItems(array $hosts): array {
+		foreach ($hosts as &$host) {
+			if ($host['items']) {
+				foreach ($host['items'] as $idx => $item) {
+					if ($item['type'] == ITEM_TYPE_HTTPTEST) {
+						unset($host['items'][$idx]);
+					}
+				}
+			}
+		}
+		unset($host);
+
+		return $hosts;
+	}
 }
