@@ -56,7 +56,7 @@ $filter_column1 = (new CFormList())
 			'popup' => [
 				'filter_preselect' => [
 					'id' => 'filter_groupids_',
-					'submit_as' => 'groupid'
+					'submit_as' => $data['context'] === 'host' ? 'groupid' : 'templategroupid'
 				],
 				'parameters' => [
 					'srctbl' => $data['context'] === 'host' ? 'hosts' : 'templates',
@@ -236,7 +236,7 @@ foreach ($data['triggers'] as $tnum => $trigger) {
 
 	if ($trigger['discoveryRule']) {
 		$description[] = (new CLink(
-			CHtml::encode($trigger['discoveryRule']['name']),
+			$trigger['discoveryRule']['name'],
 			(new CUrl('trigger_prototypes.php'))
 				->setArgument('parent_discoveryid', $trigger['discoveryRule']['itemid'])
 				->setArgument('context', $data['context'])
@@ -247,7 +247,7 @@ foreach ($data['triggers'] as $tnum => $trigger) {
 	}
 
 	$description[] = (new CLink(
-		CHtml::encode($trigger['description']),
+		$trigger['description'],
 		(new CUrl('triggers.php'))
 			->setArgument('form', 'update')
 			->setArgument('triggerid', $triggerid)
@@ -261,9 +261,8 @@ foreach ($data['triggers'] as $tnum => $trigger) {
 		foreach ($trigger['dependencies'] as $dependency) {
 			$dep_trigger = $data['dep_triggers'][$dependency['triggerid']];
 
-			$dep_trigger_desc = CHtml::encode(
-				implode(', ', array_column($dep_trigger['hosts'], 'name')).NAME_DELIMITER.$dep_trigger['description']
-			);
+			$dep_trigger_desc =
+				implode(', ', array_column($dep_trigger['hosts'], 'name')).NAME_DELIMITER.$dep_trigger['description'];
 
 			$trigger_deps[] = (new CLink($dep_trigger_desc,
 				(new CUrl('triggers.php'))
